@@ -583,10 +583,11 @@ class TickerDax:
         """
         This runs when python shuts down.
         """
-        self = globals()[GLOBAL_INSTANCE_NAME]
-        self._logger.info('Saving data to disk..')
-        self.redis_client.bgsave()
-        self._logger.info('Save complete!')
+        self = globals().get(GLOBAL_INSTANCE_NAME)
+        if self:
+            self._logger.info('Saving data to disk..')
+            self.redis_client.bgsave()
+            self._logger.info('Save complete!')
 
     def validate_api_key(self,  key_type):
         """
